
# Changelog
All notable changes to Wutta-Continuum will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.2.2 (2025-10-29)

### Fix

- exclude user password from continuum versioning

## v0.2.1 (2025-10-29)

### Fix

- add util module, w/ `model_transaction_query()`
- refactor some more for tests + pylint
- format all code with black

## v0.2.0 (2024-12-07)

### Feat

- convert all uuid fields from str to proper UUID

### Fix

- add `User.prevent_edit` to schema

## v0.1.1 (2024-08-27)

### Fix

- fix nullable flags for initial version tables

## v0.1.0 (2024-08-27)

### Feat

- initial release
